@@ -120,7 +120,12 @@ class ModelBase:
     ]
 
     def __init__(
-        self, mean: Numeric1DArray, cov: np.ndarray, *args: Any, seed: int = 0, **kwargs: Any
+        self,
+        mean: Numeric1DArray,
+        cov: np.ndarray,
+        *args: Any,
+        seed: int = 0,
+        **kwargs: Any,
     ):
         self.data = ConventionalEstimatesData(mean, cov, *args, **kwargs)
         self.seed = seed
@@ -148,9 +153,9 @@ class ModelBase:
 
         Args:
             results (LikelihoodModelResults): Conventional likelihood model estimates.
+            *args (Any): Passed to the model class constructor.
             cols (ColumnsType, optional): Names or indices of the policy variables. Defaults to
                 None.
-            *args (Any): Passed to the model class constructor.
             **kwargs (Any): Passed to the model class constructor.
 
         Returns:
@@ -189,7 +194,7 @@ class ModelBase:
             indices = np.arange(results.params.shape[0])
             exog_names = results.model.exog_names
         else:
-            indices = np.array(list(map(get_index, cols)))
+            indices = np.array([get_index(col) for col in cols])
             exog_names = [results.model.exog_names[i] for i in indices]
 
         cov = results.cov_params()
@@ -199,33 +204,59 @@ class ModelBase:
         return cls(
             pd.Series(results.params[indices], index=exog_names),
             cov[indices][:, indices],
-            endog_names=results.model.endog_names,
+            endog_names=kwargs.pop("endog_names", results.model.endog_names),
             *args,
             **kwargs,
         )
 
     @classmethod
     def from_csv(
-        cls: Type[ModelType], filename: str, *args: Any, **kwargs: Any
+        cls: Type[ModelType],
+        filename: str,
+        *args: Any,
+        cols: ColumnsType = None,
+        **kwargs: Any,
     ) -> ModelType:
         """Instantiate an estimator from csv file.
 
         Args:
             filename (str): Name of the csv file.
+            *args (Any): Passed to the model class constructor.
+            cols (ColumnsType, optional): Names or indices of the policy variables. Defaults to
+                None.
+            **kwargs (Any): Passed to the model class constructor.
 
         Returns:
             Model: Estimator.
         """
+
+        def get_index(col: Union[str, int]) -> int:
+            if isinstance(col, str):
+                return exog_names.index(col)
+            if np.isscalar(col):
+                return int(col)
+            raise ValueError(
+                f"Invalid column type {type(col)} for column {col}"
+            )  # pragma: no cover
+
         df = pd.read_csv(filename)
         mean, cov = df.values[:, 0], df.values[:, 1:]  # pylint: disable=no-member
         endog_names, exog_names = (
             df.columns[0],  # pylint: disable=no-member
             df.columns[1:],  # pylint: disable=no-member
         )
+
+        # select columns
+        if cols is None:
+            indices = np.arange(len(df))
+        else:
+            indices = np.array([get_index(col) for col in cols])
+            exog_names = [exog_names[i] for i in indices]
+
         return cls(
-            pd.Series(mean, index=exog_names),
-            cov,
-            endog_names=endog_names,
+            pd.Series(mean[indices], index=exog_names),
+            cov[indices][:, indices],
+            endog_names=kwargs.pop("endog_names", endog_names),
             *args,
             **kwargs,
         )
@@ -296,8 +327,8 @@ class ResultsBase:
         return np.array(
             [
                 dist.ppf([alpha / 2, 1 - alpha / 2])
-                for idx, dist in enumerate(self.distributions)  # type: ignore, pylint: disable=no-member
-                if idx in indices
+                for index, dist in enumerate(self.distributions)  # type: ignore, pylint: disable=no-member
+                if index in indices
             ]
         )
 
@@ -362,7 +393,6 @@ class ResultsBase:
         xname: Sequence[str] = None,
         title: str = None,
         alpha: float = 0.05,
-        params_header: List[str] = None,
     ) -> Summary:
         """Create a summary table.
 
@@ -373,7 +403,6 @@ class ResultsBase:
             title (str, optional): Table title. Defaults to None.
             alpha (float, optional): Display 1-alpha confidence interval. Defaults to
                 0.05.
-            params_header (List[str], optional): Table header. Defaults to None.
 
         Returns:
             Summary: Summary table.
@@ -384,13 +413,7 @@ class ResultsBase:
         if not hasattr(self, "pvalues"):
             raise AttributeError("Results object does not have `pvalues` attribute.")
 
-        if params_header is None:
-            params_header = [
-                "coef",
-                "pvalue",
-                f"[{alpha/2}",
-                f"{1-alpha/2}]",
-            ]
+        params_header = self._make_summary_header(alpha)
         params_data = np.hstack(
             (np.array([self.params, self.pvalues]).T, self.conf_int(alpha))  # type: ignore, pylint: disable=no-member
         )
@@ -451,3 +474,8 @@ class ResultsBase:
         ]
 
         return smry
+
+    def _make_summary_header(self, alpha: float) -> List[str]:
+        # make the header for the summary table
+        # when subclassing ResultsBase, you may wish to overwrite this method
+        return ["coef", "pvalue", f"[{alpha/2}", f"{1-alpha/2}]"]
