@@ -90,9 +90,6 @@ class BayesResults(ResultsBase):
             posterior.
         rank_matrix (pd.DataFrame): (n, n) dataframe of probabilities that column i has
             rank j.
-
-    Notes:
-        This class also contains the attributes of ``ResultsBase``.
     """
 
     def __init__(
@@ -106,7 +103,7 @@ class BayesResults(ResultsBase):
         title: str = "Bayesian estimates",
     ):
         super().__init__(model, cols, title)
-        
+
         self.params = params[self.indices]
         self.cov_params = cov_params[self.indices][:, self.indices]
         self.distributions = [
@@ -120,8 +117,9 @@ class BayesResults(ResultsBase):
             self.multivariate_distribution = multivariate_normal(
                 self.params, self.cov_params
             )
-            self.posterior_mean_rvs = self.multivariate_distribution\
-                .rvs(n_samples, random_state=seed)
+            self.posterior_mean_rvs = self.multivariate_distribution.rvs(
+                n_samples, random_state=seed
+            )
             self.rank_matrix = self._compute_rank_matrix()
         except np.linalg.LinAlgError:
             # the policy effects are perfectly correlated
@@ -174,8 +172,8 @@ class BayesResults(ResultsBase):
         Returns:
             float: Expected Wasserstein distance.
 
-        Notes:
-            `mean` and `cov` are taken to be the mean and covariance used to fit the
+        Note:
+            ``mean`` and ``cov`` are taken to be the mean and covariance used to fit the
             model by default, giving you the in-sample Wasserstein distance.
         """
 
@@ -206,8 +204,8 @@ class BayesResults(ResultsBase):
         Returns:
             float: Likelihood.
 
-        Notes:
-            `mean` and `cov` are taken to be the mean and covariance used to fit the
+        Note:
+            ``mean`` and ``cov`` are taken to be the mean and covariance used to fit the
             model by default, giving you the in-sample likelihood.
         """
         mean = self.model.mean[self.indices] if mean is None else mean
@@ -329,12 +327,15 @@ class BayesResults(ResultsBase):
 
         Args:
             singular (bool, optional): Indicates the posterior covariance matrix is
-                singular. Defaults to True.
+                singular. Defaults to False.
 
         Returns:
             pd.DataFrame: Rank matrix.
         """
-        if not singular:
+        if len(self.posterior_mean_rvs.shape) == 1:
+            # only estimating one parameter
+            rank_matrix = [1]
+        elif not singular:
             # assumes no ties in rank order
             argsort = np.argsort(-self.posterior_mean_rvs, axis=1)
             rank_matrix = np.array(
