@@ -8,6 +8,7 @@ from typing import Any, Dict, Tuple, Union
 
 import numpy as np
 from scipy.optimize import minimize_scalar
+from scipy.stats import multivariate_normal
 
 from ..base import ColumnsType, Numeric1DArray
 from .base import BayesModelBase, BayesResults
@@ -51,7 +52,7 @@ class EmpiricalBayesBase(BayesModelBase):
         Returns:
             np.ndarray: (n, n) posterior covariance matrix.
 
-        Notes:
+        Note:
             This approximation uses a plug-in estimator which likely underestimates the
             posterior covariance.
         """
@@ -174,11 +175,10 @@ class LinearEmpiricalBayes(EmpiricalBayesBase):
         max_prior_cov (float, optional): Maximum prior covariance. The prior covariance
             is assumed to be proportional to the identity matrix. Defaults to 1e6.
 
-    Notes:
-        This class' attributes are identical to those of :class:`EmpiricalBayesBase`.
-        Note that the estimated posterior covariance matrix doesn't account for
-        uncertainty in the estimated prior covariance parameter, and therefore may
-        underestimate the posterior covariance.
+    Note:
+        The estimated posterior covariance matrix doesn't account for uncertainty in the
+        estimated prior covariance parameter, and therefore may underestimate the
+        posterior covariance.
 
     Examples:
 
@@ -290,7 +290,7 @@ class LinearEmpiricalBayes(EmpiricalBayesBase):
             Tuple[PriorParams, PriorParams]: Parameters of the prior
                 distribution.
 
-        Notes:
+        Note:
             The likelihood method estimates the prior covariance parameter by maximum
             likelihood. The Wasserstein method estimates the prior covariance parameter
             by minimizing the Wasserstein distance. Likelihood is generally preferable,
@@ -328,6 +328,26 @@ class LinearEmpiricalBayes(EmpiricalBayesBase):
 
         return prior_mean_params, prior_cov_params
 
+    def prior_mean_rvs(self, size: int = 1) -> np.ndarray:
+        """Sample from the distribution of prior means.
+
+        Args:
+            size (int, optional): Number of samples to draw. Defaults to 1.
+
+        Returns:
+            np.ndarray: (size, n) array of prior mean samples.
+        """
+        # TODO: incorporate estimate_prior_params keyword arguments
+        # possibly pass in a prior_cov parameter to be consistent with heirarchical Bayes
+        _, prior_cov_params = self.estimate_prior_params()
+        prior_cov = self.estimate_prior_cov(prior_cov_params)
+        X_T = self.X.T
+        tau_inv = np.linalg.inv(prior_cov + self.cov)
+        XT_tauinv_X_inv = np.linalg.inv(X_T @ tau_inv @ self.X)
+        beta_bar = XT_tauinv_X_inv @ X_T @ tau_inv @ self.mean
+        beta = multivariate_normal.rvs(beta_bar, XT_tauinv_X_inv, size=size)
+        return (self.X @ beta.reshape(1, -1)).squeeze()
+
     def _estimate_prior_mean_params(self, prior_cov: np.ndarray) -> np.ndarray:
         """Estimate prior mean parameter vector.
 
@@ -369,9 +389,11 @@ class LinearEmpiricalBayes(EmpiricalBayesBase):
 
 
 class JamesStein(EmpiricalBayesBase):
-    """James-Stein estimator. Inherits from :class:`EmpiricalBayesBase`.
+    """James-Stein estimator.
 
-    Notes:
+    Inherits from :class:`EmpiricalBayesBase`.
+
+    Note:
         This estimator is most appropriate when the sample covariance matrix is
         proportional to the identity matrix.
 
