@@ -34,8 +34,8 @@ class RQUData(ConventionalEstimatesData):
             effects. Defaults to None.
         ycov (np.ndarray, optional): (n,n) covariance matrix of ``ymean``. Defaults to
             None.
-        xycov (np.ndarray, optional): (n,n) covariance matrix of ``xparamx`` and
-            ``ymean``. Defaults to None.
+        xycov (np.ndarray, optional): (n,n) covariance matrix of ``mean`` and ``ymean``.
+            Defaults to None.
 
     Attributes:
         mean (np.ndarray): (n,) array of conventional estimates used to rank-order
@@ -50,6 +50,15 @@ class RQUData(ConventionalEstimatesData):
             ``cov``.
         xycov (np.ndarray): (n,n) covariance matrix of ``mean`` and ``ymean``. If
             ``None``, use ``cov``.
+
+    Note:
+
+        By default, we assume that the conventional estimates used to rank policies are
+        the same as the conventional estimates of the policy effects. If this is not the
+        case, set ``mean`` and ``cov`` to the conventional estimates used to rank the
+        policies and ``ymean`` and ``ycov`` to the conventional estimates of the policy
+        effects. You must also set ``xycov`` to the covariance matrix of ``mean`` and
+        ``ymean``.
     """
 
     def __init__(  # pylint: disable=too-many-arguments
@@ -182,9 +191,10 @@ class RQU(ModelBase):
             Union[ProjectionResults, RQUResults]: Quantile-unbiased estimation results.
 
         Examples:
+
             Suppose we have 5 policies, each with a true effect of 0. The observed
-                effect of the policies is sampled from a joint normal with identity
-                covariance matrix.
+            effect of the policies is sampled from a joint normal with identity
+            covariance matrix.
 
             .. code-block:: python
 
@@ -257,7 +267,7 @@ class RQU(ModelBase):
                 index = np.argsort(-self.mean)[rank]
             else:
                 index = self._get_index(col)
-                exact_rank = (self.mean > self.mean[col]).sum()
+                exact_rank = (self.mean > self.mean[index]).sum()
                 if isinstance(rank, str):
                     if rank == "exact":
                         rank = exact_rank
@@ -287,7 +297,7 @@ class RQU(ModelBase):
                 )
 
         def compute_truncation_set():
-            # compute the trucation set for `truncated_cdf`
+            # compute the trucation set for `truncnorm.cdf`
             # see paper for details on this algorithm
 
             def update_truncation_set(idx, j):
@@ -373,14 +383,15 @@ class RQU(ModelBase):
         Returns:
             List[quantile_unbiased]: Quantile-unbiased distributions of policy effects.
         """
+        indices = self.get_indices(cols)
         if beta == 0:
-            return [self.get_distribution(i, **kwargs) for i in self.get_indices(cols)]
+            return [self.get_distribution(i, **kwargs) for i in indices]
         projection_intervals = self.compute_projection_quantile(
             beta, n_samples
-        ) * np.sqrt(self.ycov.diagonal())
+        ) * np.sqrt(self.ycov[indices][:, indices].diagonal())
         return [
             self.get_distribution(i, projection_interval=interval, **kwargs)
-            for i, interval in zip(self.get_indices(cols), projection_intervals)
+            for i, interval in zip(indices, projection_intervals)
         ]
 
     def projection_rvs(self, size: int = 1) -> np.ndarray:
@@ -420,8 +431,8 @@ class ProjectionResults(ResultsBase):
             projection CIs.
         pvalues (np.ndarray): (n,) array of probabilities that the true effect of a
             policy is less than 0.
-        std_params_diag (np.ndarray): (n,) array of standard deviations from the `mean`
-            covariance matrix.
+        std_params_diag (np.ndarray): (n,) array of standard deviations from the
+            ``mean`` covariance matrix.
 
     Examples:
 
@@ -482,46 +493,22 @@ class ProjectionResults(ResultsBase):
             np.ndarray: (n,2) array of confidence intervals.
         """
         indices = self.indices if cols is None else self.model.get_indices(cols)
+        select = [np.where(self.indices == index)[0][0] for index in indices]
         c_alpha = np.quantile(abs(self.projection_rvs).max(axis=1), 1 - alpha)
         return np.array(
             [
                 self.params - c_alpha * self.std_params_diag,
                 self.params + c_alpha * self.std_params_diag,
             ]
-        ).T[self.indices[indices.argsort()]]
+        ).T[select]
 
-    def summary(
-        self,
-        yname: str = None,
-        xname: Sequence[str] = None,
-        title: str = None,
-        alpha: float = 0.05,
-        params_header: List[str] = None,
-    ) -> Summary:
-        """Create a summary table.
-
-        Args:
-            yname (str, optional): Name of the endogenous variable. Defaults to None.
-            xname (Sequence[str], optional): Names of the exogenous variables. Defaults
-                to None.
-            title (str, optional): Table title. Defaults to None.
-            alpha (float, optional): Display 1-alpha confidence interval. Defaults to
-                0.05.
-            params_header (List[str], optional): Table header. Defaults to None.
-
-        Returns:
-            Summary: Summary table.
-        """
-        if params_header is None:
-            params_header = [
-                "coef (conventional)",
-                "pvalue",
-                f"{1-alpha} CI lower",
-                f"{1-alpha} CI upper",
-            ]
-        return super().summary(
-            yname, xname, title=title, alpha=alpha, params_header=params_header
-        )
+    def _make_summary_header(self, alpha: float) -> List[str]:
+        return [
+            "coef (conventional)",
+            "pvalue",
+            f"{1-alpha} CI lower",
+            f"{1-alpha} CI upper",
+        ]
 
 
 class RQUResults(ResultsBase):
@@ -607,35 +594,5 @@ class RQUResults(ResultsBase):
         alpha = (alpha - self.beta) / (1 - self.beta)
         return super().conf_int(alpha, cols)
 
-    def summary(
-        self,
-        yname: str = None,
-        xname: Sequence[str] = None,
-        title: str = None,
-        alpha: float = 0.05,
-        params_header: List[str] = None,
-    ) -> Summary:
-        """Create a summary table.
-
-        Args:
-            yname (str, optional): Name of the endogenous variable. Defaults to None.
-            xname (Sequence[str], optional): Names of the exogenous variables. Defaults
-                to None.
-            title (str, optional): Table title. Defaults to None.
-            alpha (float, optional): Display 1-alpha confidence interval. Defaults to
-                0.05.
-            params_header (List[str], optional): Table header. Defaults to None.
-
-        Returns:
-            Summary: Summary table.
-        """
-        if params_header is None:
-            params_header = [
-                "coef (median)",
-                "pvalue",
-                f"[{alpha/2}",
-                f"{1-alpha/2}]",
-            ]
-        return super().summary(
-            yname, xname, title=title, alpha=alpha, params_header=params_header
-        )
+    def _make_summary_header(self, alpha: float) -> List[str]:
+        return ["coef (median)", "pvalue", f"[{alpha/2}", f"{1-alpha/2}]"]
